@@ -6,7 +6,7 @@ import pygame
 class Feedback(Enum):
     COLLISION = 0, "Collision"
     MOVED = 1, "Moved"
-    IS_ON_PIZZA = 2, "Is_on_pizza"
+    MOVED_ON_PIZZA = 2, "Moved_on_pizza"
     TOUCHED_WALL = 3, "Touched_wall"
     TOUCHED_NOTHING = 4, "Touched_nothing"
     TOUCHED_PIZZA = 5, "Touched_pizza"
